# 事件处理函数

* 事件处理函数不能接收任何参数.

示例:

```jsx
function greet() {alert('hello!')}  // 定义事件处理函数 greet
```

# JSX 标签的事件属性

* 事件属性的值必须以模板语法的方式传入.

示例:

```jsx
function MyButton() {
    // 事件处理函数; 它将被以模板语法的方式传递给事件属性onClick
    function greet() {alert('hello!')}

    return (
        <button onClick={greet}>点击我</button>
    )
}
```

## 事件属性表

| jsx 标签事件属性 | 对应的普通 html 标签事件属性 |
| :--------------: | :--------------------------: |
|     onClick     |           onclick           |

# Hook

* 以 `use` 开头的函数被称为 `Hook` .
* 由于 react 的内部实现不够完美, 目前只能在组件(或其它 hook)的顶层调用 hook, 而不能在 if 语句或循环语句中调用 hook . 例如: 不能在 if 代码块中执行 `const [count, setCount] = useState(0)` .

## 内置 Hook

react 内置了一些常用的 hook, 这些内置的 hook 可以在 [React 内置 Hook](https://zh-hans.react.dev/reference/react/hooks) 中找到.

### useState

使用示例:

```jsx
import { useState } from 'react'

// 定义一个叫 MyButton 的组件, 该组件接收 total 和 on_click 这两个变量.
function MyButton({ total, on_click }) {
    return (
        <button onClick={on_click}>两个按钮共点了 {total} 次</button>
    )
}

function MyApp() {
    const [count, setCount] = useState(0)  // 在顶层调用 useState
  
    // 创建一个事件处理函数
    function greet() {
        setCount(count + 1)  // 在 react 中, state 是只读的, 你不能直接修改它, 而必须用 setState 方法
    }

    return (
        <div>
            <h1>共同更新的计数器</h1>
            <MyButton total={count} on_click={greet} />
            <MyButton total={count} on_click={greet} />
        </div>
    )
}
```

在生成的两个按钮中, 点击任何一个按钮, 两个按钮的计数都会变化.

# 组件传参

如果你能理解上文的 [useState 使用示例](#usestate) 中的 MyButton 是如何接收参数的, 那么你便理解了组件传参的一般用法. 如果你想了解更多用法, 请参考 [https://zh-hans.react.dev/learn/passing-props-to-a-component](https://zh-hans.react.dev/learn/passing-props-to-a-component) .
