# 组件的定义

* react 组件是返回 jsx 标签的函数, 一个组件就是一个函数. (后文会具体介绍 jsx 标签)
* 组件返回的 jsx 标签需要用括号包起来.
* 组件名(即函数名)必须以大写字母开头.
* 一个组件只能返回一个 jsx 标签.
* 任何 jsx 标签都必须闭合.

组件示例:

```jsx
function MyButton() {
    return (<button>我是一个按钮</button>)
}

```

组件示例:

```jsx
let MyButton = () => (<button>我是一个按钮</button>)
```

# 组件的导入

示例:

```jsx
import {MyButton} from 'my_components.js'
```

# 组件的调用

一个定义好的组件, 可以直接被作为一个自闭合标签使用.

#### 示例

在下面的示例中, 组件 `MyButton` 被作为一个自闭合标签使用:

```jsx
function MyApp() {
    return (
        <div>
            <h1>欢迎来到我的应用</h1>
            <MyButton />
        </div>
    )
}
```

由于组件的本质是函数, 因此调用一个组件时, 本质上是把一个函数当成标签来使用. 比如, 在上文中, 我们定义 `MyButton` 时, 是使用 `function MyButton()` 这种形式定义, 而调用时则是使用 `<MyButton />` 这种形式调用.

# JSX 标签

## JSX 标签的属性

| jsx 标签属性 | 对应的普通 html 标签属性 |           说明           |
| :----------: | :----------------------: | :----------------------: |
|  className  |          class          |                          |
|     src     |           src           |                          |
|    style    |          style          | 用法与普通 html 标签不同 |

JSX 标签属性的特性:

* 属性值除了字符串以外, 其它类型的值必须以模板语法的方式传入.

## JSX 标签的模板语法

* 模板语法应使用花括号 `{}` 包起来.
* 在模板语法中, 可以使用任意 `JavaScript` 语法.

使用示例:

```jsx
function SecondsCount() {
    return (
        <div>
            <h1>一天有多少秒?</h1>
            <div>一天有{3600 * 24}秒</div>
        </div>
    )
}
```

## JSX 标签的特殊属性

### style

* 属性值必须是一个 js 字典. (由于属性值为非字符串类型, 因此必须以模板语法表示)

style 属性值示例:

```jsx
const StyleValue = {width: 90, height: 90}  // 属性值必须是一个 js 字典

function Profile() {
    return (
        <div>
            <img className="avatar" style={StyleValue} />
        </div>
    )
}
```

style 属性值示例:

```jsx
function Profile() {
    return (
        <div>
            <img className="avatar" style={ {width: 90, height: 90} } />
        </div>
    )
}
```

## JSX 标签的特性

### 可被赋值给一个变量

示例:

```jsx
function Demo() {
    let content = <AdminPanel />  // 赋值给变量 content
    return (
        <div>
            {content}
        </div>
    )
}
```

### 模板语法可以直接渲染一个 jsx 标签数组

* react 的 jsx 模板语法支持直接渲染一个数组, react 会自动把数组的每个元素都渲染出来.
* 由于 react 的内部实现不够完美, 目前在渲染一个数组时, 数组的每个元素(元素类型为 jsx 标签)都必须含有 key 属性, 且元素的 key 属性值不能重复.

示例:

```jsx
function Demo() {
    const list_items = []

    const products = [
        { title: 'Cabbage', id: 1 },
        { title: 'Garlic', id: 2 },
        { title: 'Apple', id: 3 },
    ]

    for (let product of products) {
        let x = <li key={product.id}>{product.title}</li>
        list_items.push(x)
    }

    return (<ul>{list_items}</ul>)
}
```
