# Python忍术·咒印之术 —— 装饰器完全指南

在《火影忍者》中，**咒印**是大蛇丸独特的忍术之一，它可以在忍者身上留下一个特殊的印记，使其获得额外的能力。例如，佐助的 **天之咒印** 赋予了他更强的查克拉和战斗力，但也带来了副作用。

在 Python 中，也有类似**咒印**的机制——**装饰器**。装饰器可以增强函数的功能，而无需修改原始代码，就像咒印可以赋予忍者额外的能力，而不改变他们的基本技能。

---

## **一、咒印 vs. Python 装饰器**

在火影世界中，咒印的作用：

- 赋予忍者**额外的能力**（如佐助的天之咒印、君麻吕的地之咒印）。
- **不会改变忍者的本体**，但会影响他们的行为。
- 可以**随时开启或关闭**，但需要**特殊的条件**（如查克拉消耗）。
- 可能有**副作用**，如果不加以控制，可能导致暴走。

Python 的 **装饰器** 也有类似的特点：

- **给函数或类添加新功能**，不改变原始代码。
- **函数本体不变**，只是额外包裹了一层功能。
- **可以动态启用或禁用**，增强代码的灵活性。
- **可能带来额外开销**（如运行时性能影响）。

---

## **二、Python 装饰器的基本用法**

Python 中的装饰器通常用于 **修改或增强函数的行为**，就像在忍者身上施加咒印。

### **1. 定义一个基础装饰器（咒印）**

假设我们有一个普通的 **火遁·豪火球之术**：

```python
def fireball():
    print("🔥 火遁·豪火球之术！")
```

现在，我们想给这个技能施加 **咒印状态**，让它变得更强，但不改变原来的 `fireball()` 代码：

```python
def curse_mark(func):
    def wrapper():
        print("🌀 天之咒印·解放！")
        func()
        print("🔥 查克拉暴增！技能威力提升！")
    return wrapper

# 使用装饰器（施加咒印）
fireball = curse_mark(fireball)

fireball()
```

### **输出**

```
🌀 天之咒印·解放！
🔥 火遁·豪火球之术！
🔥 查克拉暴增！技能威力提升！
```

这里的 **`curse_mark`** 就是一个装饰器，它在函数 `fireball()` 执行前后增加了额外的功能，类似于**咒印解放**的效果。

---

## **三、使用 `@` 语法糖（更优雅的咒印）**

在 Python 中，我们可以用 `@` 语法更简洁地应用装饰器，就像**直接施加咒印**。

```python
def curse_mark(func):
    def wrapper():
        print("🌀 天之咒印·解放！")
        func()
        print("🔥 查克拉暴增！技能威力提升！")
    return wrapper

@curse_mark  # 直接在函数上加上咒印
def chidori():
    print("⚡ 雷遁·千鸟！")

chidori()
```

### **输出**

```
🌀 天之咒印·解放！
⚡ 雷遁·千鸟！
🔥 查克拉暴增！技能威力提升！
```

🔹 **装饰器的 `@curse_mark` 语法**，让代码更清晰，就像忍者身上的咒印一样，一旦触发，就能增强能力。

---

## **四、带参数的装饰器（不同等级的咒印）**

不同的忍者可能拥有不同等级的咒印，比如佐助的**第一阶段**和**第二阶段**咒印。

### **1. 让装饰器接受参数**

```python
def curse_mark(level):
    def decorator(func):
        def wrapper():
            print(f"🌀 咒印·Lv{level} 解放！")
            func()
            print(f"🔥 查克拉暴增 Lv{level}！技能威力提升！")
        return wrapper
    return decorator

@curse_mark(2)  # 施加二阶段咒印
def amaterasu():
    print("🔥 天照！黑炎不灭！")

amaterasu()
```

### **输出**

```
🌀 咒印·Lv2 解放！
🔥 天照！黑炎不灭！
🔥 查克拉暴增 Lv2！技能威力提升！
```

🔹 **装饰器可以接受参数**，让我们能动态调整咒印的强度，就像忍者能控制自己的查克拉输出。

---

## **五、装饰多个技能（多个咒印）**

如果佐助不仅有咒印，还拥有 **写轮眼**，那么我们可以**施加多个装饰器**：

```python
def sharingan(func):
    def wrapper():
        print("👁️ 万花筒写轮眼·开启！")
        func()
        print("🔮 预判敌人动作，提高命中率！")
    return wrapper

@curse_mark(2)  # 先施加咒印
@sharingan      # 再施加写轮眼
def kirin():
    print("⚡ 雷遁·麒麟！")

kirin()
```

### **输出**

```
👁️ 万花筒写轮眼·开启！
🌀 咒印·Lv2 解放！
⚡ 雷遁·麒麟！
🔥 查克拉暴增 Lv2！技能威力提升！
🔮 预判敌人动作，提高命中率！
```

🔹 **多个装饰器的执行顺序是从下往上**：

1. **先触发 `sharingan`**（写轮眼开启）
2. **再触发 `curse_mark(2)`**（咒印解放）
3. **最后执行 `kirin()` 技能**

---

## **六、类方法装饰器（适用于整个忍者）**

有时候，我们希望**整个忍者的所有技能**都受到咒印的影响，而不仅仅是单个技能。可以使用 **类方法装饰器** 来实现：

```python
def curse_mark_class(cls):
    class Wrapper:
        def __init__(self, *args, **kwargs):
            self.instance = cls(*args, **kwargs)

        def __getattr__(self, attr):
            original_attr = getattr(self.instance, attr)
            if callable(original_attr):  # 如果是方法，就增强
                def wrapper(*args, **kwargs):
                    print("🌀 天之咒印·解放！")
                    result = original_attr(*args, **kwargs)
                    print("🔥 查克拉暴增！技能威力提升！")
                    return result
                return wrapper
            return original_attr
    return Wrapper

@curse_mark_class
class Ninja:
    def fireball(self):
        print("🔥 火遁·豪火球之术！")

    def chidori(self):
        print("⚡ 雷遁·千鸟！")

sasuke = Ninja()
sasuke.fireball()
sasuke.chidori()
```

### **输出**

```
🌀 天之咒印·解放！
🔥 火遁·豪火球之术！
🔥 查克拉暴增！技能威力提升！
🌀 天之咒印·解放！
⚡ 雷遁·千鸟！
🔥 查克拉暴增！技能威力提升！
```

🔹 这样，整个 `Ninja` 类的所有技能都会自动带上咒印效果，类似于 **佐助开启咒印模式，所有技能都增强**！

---

## **七、总结**

| 🔥 装饰器                   | 🌀 咒印                        |
| --------------------------- | ------------------------------ |
| `@curse_mark` 施加功能    | 忍者身上刻下咒印               |
| 函数增强但本体不变          | 忍者获得额外能力但仍是原本实力 |
| `@curse_mark(level)` 传参 | 不同等级的咒印强度             |
| 多个装饰器                  | 咒印+写轮眼的组合              |
| 类装饰器                    | 整个忍者都受影响               |

Python 的装饰器就像咒印，可以让代码更强大、更灵活，但也要小心**滥用**，否则可能导致代码可读性变差，就像咒印暴走可能导致忍者失控！🔥🔥🔥
